rm(list=ls())

options(scipen = 999)

library(tidytree)
library(tidyr)
library(ggtree)
library(data.tree)
library(RColorBrewer)
library(dplyr)
library(ggpubr)

#load data
df_to_plot <- read.csv('/eos/jeodpp/data/projects/REFOCUS/data/phylogentree/HCAT2mergedWithAggregation_allinfo.csv', stringsAsFactors = F)

#remove characteristics central node
df_to_plot_cropTypeRow <- df_to_plot[c(which(df_to_plot$pathString == 'characteristics/crop_type')),]
df_to_plot <- df_to_plot[-c(which(df_to_plot$pathString == 'characteristics/crop_type')),]
df_to_plot$pathString <- gsub('/NA','',paste(df_to_plot$level2_name, df_to_plot$level3_name, df_to_plot$level4_name, df_to_plot$level5_name, df_to_plot$level6_name, sep='/'))

#to node 
df_node <- as.Node(df_to_plot,pathName = "pathString",pathDelimiter = "/",heightName = "hierarchic_level") #8 nodes w/ 344 sub    

#to tree - returns the underscores - why?
tree <- as.phylo(df_node)

#make df fit tree structure
dat <- data.frame(HCAT2_name = tree$tip.label)

#fit the size 1.1 - works
dat_NL <- merge(dat, df_to_plot[,c(2,3,5,22,34,27,30,31)], by = 'HCAT2_name', all.x = T, all.y = T)
dat_FR <- merge(dat, df_to_plot[,c(1,3,5,21,35,28,29,32)], by = 'HCAT2_name', all.x = T, all.y = T)

#add back crop_type row - should we do it?
dat_NL <- rbind(dat_NL, df_to_plot_cropTypeRow[,c(2,3,5,22,34,27,30,31)])
dat_FR <- rbind(dat_FR, df_to_plot_cropTypeRow[,c(1,3,5,21,35,28,29,32)])

#rename cols
colnames(dat_NL) <- c('HCAT2_name', 'HCAT2 aggregated class', 'HCAT2_code', 'Number of parcels', '% of all parcels', 'node_NL', 'Availability NL', 'colorRGB_NL')
colnames(dat_FR) <- c('HCAT2_name', 'HCAT2 aggregated class', 'HCAT2_code', 'Number of parcels', '% of all parcels', 'node_FR', 'Availability FR', 'colorRGB_FR')

row.names(dat_NL) <- seq(1, nrow(dat_NL))

#OG working version
p_nl <- ggtree(tree, layout='circular') %<+% dat_NL+#[,c(3,2,4,5,1,6)] + #column mapped to color for some reason cannot be first in the df ???
  geom_nodelab(size=5, color = 'black') + aes(color = `HCAT2 aggregated class`) +
  #scale_color_manual('', breaks = dat_NL$HCAT2_name, values = c(dat_NL$colorRGB), labels = c(dat_NL$SPECIES))+
  geom_point2(aes(subset=(node==node_NL), size = `% of all parcels`))+ #, alpha = ifelse(is.na(distrib_NL), 0.5, 1)
  geom_tiplab(aes(alpha = ifelse(`Availability NL` == 0, 0.5, 1)),offset=.5, size=3)+hexpand(.05)+
  theme(legend.position = 'top', legend.title = element_blank())+
  theme_void(base_size = 15)

ggtree(tree, layout='circular') %<+% dat_NL+#[,c(3,2,4,5,1,6)] + #column mapped to color for some reason cannot be first in the df ???
  geom_nodelab(size=5, color = 'black') + aes(color = `HCAT2 aggregated class`) +
  #scale_color_manual('', breaks = dat_NL$HCAT2_name, values = c(dat_NL$colorRGB), labels = c(dat_NL$SPECIES))+
  geom_point2(aes(subset=(node==c(54)), size = c(100)))+ #, alpha = ifelse(is.na(distrib_NL), 0.5, 1)
  geom_tiplab(aes(alpha = ifelse(`Availability NL` == 0, 0.5, 1)),offset=.5, size=3)+hexpand(.05)+
  theme(legend.position = 'top', legend.title = element_blank())+
  theme_void(base_size = 15)

file_name <- 'NL_phgen_3.png'
plot.dir <- '/eos/jeodpp/data/projects/REFOCUS/data/phylogentree/figs_all/'
ggsave(filename=file_name,plot = p_nl,
       scale = 1, width = 255*3, height =150*3 ,units = "mm",
       dpi = 300,path=plot.dir)
