rm(list=ls())

options(scipen = 999)

library(tidytree)
library(tidyr)
library(ggtree)
library(data.tree)
library(RColorBrewer)
library(dplyr)
library(ggpubr)

#load data
work.dir=paste0('/eos/jeodpp/home/users/andrrap/data/CASE-STUDY-X-CropDeepTrans/')
df <- read.csv(paste0(work.dir,'data/','HCAT2mergedWithAggregation.csv'))
df_to_plot <-df

#remove first row (characteristics) and remake the pathString or?
df_to_plot <- df_to_plot[-c(1),]
df_to_plot$pathString <- gsub('/NA','',paste(df_to_plot$level2_name, df_to_plot$level3_name, df_to_plot$level4_name, df_to_plot$level5_name, df_to_plot$level6_name, sep='/'))

#remove underscore from name ? doesnt seem to be possible
#df_to_plot <- as.data.frame(apply(df_to_plot, 2, function(y) as.character(gsub("_", " ", y))))
#df_to_plot$HCAT2_name <- gsub('_',' ',df_to_plot$HCAT2_name)
#df_to_plot$HCAT2_name_aggregated_NL <- gsub('_',' ',df_to_plot$HCAT2_name_aggregated_NL)
#df_to_plot$HCAT2_name_aggregated_FR <- gsub('_',' ',df_to_plot$HCAT2_name_aggregated_FR)

#to node 
df_node <- as.Node(df_to_plot,pathName = "pathString",pathDelimiter = "/",heightName = "hierarchic_level") #8 nodes w/ 284 sub    

#to tree - returns the underscores - why?
tree <- as.phylo(df_node)

#make df fit tree structure
dat <- data.frame(SPECIES = tree$tip.label)

#fit the size 1.1 - works
dat_NL <- merge(dat, df_to_plot[,c(2,3,20,25)], by.x = 'SPECIES', by.y = 'HCAT2_name', all.x = T, all.y = T)
dat_FR <- merge(dat, df_to_plot[,c(2,3,19,22)], by.x = 'SPECIES', by.y = 'HCAT2_name', all.x = T, all.y = T)

#fit the size 1.1 - works- 2 check tst
#dat_NL <- merge(dat, df_to_plot[,c(2,3,20,25)], by.x = 'SPECIES', by.y = 'HCAT2_name', all.x = T, all.y = F)
# <- merge(dat, df_to_plot[,c(2,3,19,22)], by.x = 'SPECIES', by.y = 'HCAT2_name', all.x = T, all.y = F)

#get node ids = OG AND WORKING
hcat2_nodes <- read.csv('/eos/jeodpp/data/projects/REFOCUS/data/phylogentree/HCAT2mergedWithAggregation_nodeid.csv', stringsAsFactors = F)
dat_NL <- merge(dat_NL, hcat2_nodes[,c(3,15)], by.x = 'SPECIES', by.y = 'HCAT2_name', all.x = T, all.y = T)
dat_FR <- merge(dat_FR, hcat2_nodes[,c(3,16)], by.x = 'SPECIES', by.y = 'HCAT2_name', all.x = T, all.y = T)

# #get the nodes in subset
# hcat2_nodes <- read.csv('/eos/jeodpp/data/projects/REFOCUS/data/phylogentree/HCAT2mergedWithAggregation_nodeid.csv', stringsAsFactors = F)
# hcat2_nodes_NL <- hcat2_nodes[hcat2_nodes$HCAT2_code %in% dat_NL$HCAT2_code,]
# hcat2_nodes_FR <- hcat2_nodes[hcat2_nodes$HCAT2_code %in% dat_FR$HCAT2_code,]
# dat_NL <- merge(dat_NL, hcat2_nodes_NL[,c(3,15)], by.x = 'SPECIES', by.y = 'HCAT2_name', all.x = T, all.y = T)
# dat_FR <- merge(dat_FR, hcat2_nodes_FR[,c(3,16)], by.x = 'SPECIES', by.y = 'HCAT2_name', all.x = T, all.y = T)


#get the availability in 2 - ifelse
hcat2_available <- read.csv('/eos/jeodpp/data/projects/REFOCUS/data/phylogentree/hcat2_fr_nl.csv', stringsAsFactors = F)
dat_NL$availability <- ifelse(dat_NL$HCAT2_code %in% hcat2_available$hcat2_code[hcat2_available$nl == 1], 1, 0)
dat_FR$availability <- ifelse(dat_FR$HCAT2_code %in% hcat2_available$hcat2_code[hcat2_available$fr == 1], 1, 0)

#add the crop_type back
dat_NL$HCAT2_name_aggregated_NL[dat_NL$SPECIES == 'crop_type'] <- 'crop_type'
dat_NL$HCAT2_code[dat_NL$SPECIES == 'crop_type'] <- 3300000000
dat_NL$distrib_NL[dat_NL$SPECIES == 'crop_type'] <- 7422
#dat_NL$colorRGB[dat_NL$SPECIES == 'crop_type'] <- '#ffffff'

#convert distro to percentage
dat_NL$distro_perc <- round((dat_NL$distrib_NL / sum(dat_NL$distrib_NL[!is.na(dat_NL$distrib_NL)])) * 100, 2)
dat_FR$distro_perc <- round((dat_FR$distrib_FR / sum(dat_FR$distrib_FR[!is.na(dat_FR$distrib_FR)])) * 100, 2)

colnames(dat_NL) <- c('SPECIES', 'HCAT2_code', 'Number of parcels', 'HCAT2 aggregated class', 'node_NL', 'availability' ,'% of all parcels')#,'colorRGB')
#colnames(dat_NL) <- c('HCAT2_code', 'SPECIES', 'Number of parcels', 'HCAT2 aggregated class', 'node_NL' ,'% of all parcels')#,'colorRGB')



#OG working version
p_nl <- ggtree(tree, layout='circular') %<+% dat_NL+#[,c(3,2,4,5,1,6)] + #column mapped to color for some reason cannot be first in the df ???
  geom_nodelab(size=4, color = 'black') + aes(color = `HCAT2 aggregated class`)+#, alpha = ifelse(available_flag == 0, 0, 1)) +
  #scale_color_manual(values = c(dat_NL$colorRGB), labels = c(dat_NL$SPECIES))+
  geom_point2(aes(subset=(node==node_NL), size = `% of all parcels`))+ #, alpha = ifelse(is.na(distrib_NL), 0.5, 1)
  geom_tiplab(aes(alpha = ifelse(availability == 0, 0.99, 1)), offset=.5, size=2)+hexpand(.05)+
  theme(legend.position = 'right')+
  guides(alpha = 'none')


# #testing for colors
# #colors - not working yet
# colors_csv <- read.csv('/eos/jeodpp/data/projects/REFOCUS/data/phylogentree/legend-crop-colour.csv', stringsAsFactors = F)
# dat_NL <- merge(dat_NL, colors_csv[,c(1,2)], by.x = 'HCAT2_name_aggregated_NL', by.y = 'HCAT2_name', all.x = T)
# dat_FR <- merge(dat_FR, colors_csv, by.x = 'HCAT2_name_aggregated_FR', by.y = 'HCAT2_name', all.x = T)
# colnames(dat_NL) <- c('HCAT2 aggregated class', 'SPECIES', 'HCAT2_code', 'Number of parcels', 'node_NL', '% of all parcels')#,'colorRGB')
# 
# dat_NL$HCAT2_name_aggregated_NL[dat_NL$SPECIES == 'crop_type'] <- 'crop_type'
# dat_NL$HCAT2_code[dat_NL$SPECIES == 'crop_type'] <- 3300000000
# dat_NL$distrib_NL[dat_NL$SPECIES == 'crop_type'] <- 7422
# dat_NL$colorRGB[dat_NL$SPECIES == 'crop_type'] <- '#ffffff'
# 
# p_nl <- ggtree(tree, layout='circular') %<+% dat_NL[,c(3,2,4,5,1,6)] + #column mapped to color for some reason cannot be first in the df ???
#   geom_nodelab(size=2, color = 'black') + aes(color = `HCAT2 aggregated class`) +
#   scale_color_manual(values = c(dat_NL$colorRGB), labels = c(dat_NL$SPECIES))+
#   geom_point2(aes(subset=(node==node_NL), size = `% of all parcels`))+ #, alpha = ifelse(is.na(distrib_NL), 0.5, 1)
#   geom_tiplab(offset=.5, size=1)+hexpand(.05)+
#   theme(legend.position = 'top', legend.title = element_blank())
# 
# # file_name <- 'NL_phgen_2.svg'
# # plot.dir <- '/eos/jeodpp/data/projects/REFOCUS/data/phylogentree/figs_all/'
# # ggsave(filename=file_name,plot = p_nl,
# #        scale = 1, width = 255, height =150 ,units = "mm",
# #        dpi = 300,path=plot.dir)
# # END testing for colors


#without color name change
colnames(dat_FR) <- c('SPECIES', 'HCAT2_code','Number of parcels', 'HCAT2 aggregated class', 'node_FR', 'availability', '% of all parcels')#,'colorRGB')

#OG working version
p_fr <- ggtree(tree, layout='circular') %<+% dat_FR +
  geom_nodelab(size=4, color = 'black') + aes(color=`HCAT2 aggregated class`)+
  geom_point2(aes(subset=(node==node_FR), size = `% of all parcels`))+ #, alpha = ifelse(is.na(dat_FR$distrib_FR), 0.5, 1)
  geom_tiplab(aes(alpha = ifelse(availability == 0, 0.99, 1)), offset=.5, size=2)+hexpand(.05)+
  theme(legend.position = 'right')+
  guides(alpha = 'none')
  

# #testing for colors
# #colnames(dat_FR) <- c('SPECIES', 'HCAT2_code', 'Number of parcels', 'HCAT2 aggregated class', 'node_FR')
# 
# p_fr <- ggtree(tree, layout='circular') %<+% dat_FR +
#   geom_nodelab(size=2, color = 'black') + aes(color=`HCAT2 aggregated class`)+
#   geom_point2(aes(subset=(node==node_FR), size = `% of all parcels`))+ #, alpha = ifelse(is.na(dat_FR$distrib_FR), 0.5, 1)
#   geom_tiplab(offset=.5, size=1)+hexpand(.05)+
#   theme(legend.position = 'top', legend.title = element_blank())
# 
# # file_name <- 'FR_phgen_1.png'
# # plot.dir <- '/eos/jeodpp/data/projects/REFOCUS/data/phylogentree/figs_all/'
# # ggsave(filename=file_name,plot = p_fr,
# #        scale = 1, width = 255, height =150 ,units = "mm",
# #        dpi = 300,path=plot.dir)
# ##END testing for colors


#arrange to single plot
p_all <- ggarrange(p_nl, p_fr, ncol = 1 ,labels = c('NL', 'FR'), common.legend = F)

file_name <- 'all_phgen_1.png'
plot.dir <- '/eos/jeodpp/data/projects/REFOCUS/data/phylogentree/figs_all/'
ggsave(filename=file_name,plot = p_all,
       scale = 1, width = 450, height = 620 ,units = "mm",
       dpi = 300,path=plot.dir)
