rm(list=ls())

hcat2_base <- read.csv('/eos/jeodpp/data/projects/REFOCUS/data/phylogentree/HCAT2mergedWithAggregation.csv', stringsAsFactors = F)
hcat2_nodeid <- read.csv('/eos/jeodpp/data/projects/REFOCUS/data/phylogentree/HCAT2mergedWithAggregation_nodeid.csv', stringsAsFactors = F)
hcat2_avail <- read.csv('/eos/jeodpp/data/projects/REFOCUS/data/phylogentree/hcat2_fr_nl.csv', stringsAsFactors = F)
hcat2_color <- read.csv('/eos/jeodpp/data/projects/REFOCUS/data/phylogentree/legend-crop-colour.csv', stringsAsFactors = F)

#base and nodeid
nrow(hcat2_base) == nrow(hcat2_nodeid)
length(unique(hcat2_base$HCAT2_code)) == length(unique(hcat2_nodeid$HCAT2_code))
length(unique(hcat2_base$HCAT2_name)) == length(unique(hcat2_nodeid$HCAT2_name))
length(unique(hcat2_base$HCAT2_code_aggregated_NL)) == length(unique(hcat2_nodeid$HCAT2_name_aggregated_NL))
length(unique(hcat2_base$HCAT2_code_aggregated_FR)) == length(unique(hcat2_nodeid$HCAT2_name_aggregated_FR))

#merge base with nodeid
hcat2_base_nodeid <- merge(hcat2_base, hcat2_nodeid[,c(2,15,16)], by = 'HCAT2_code', all=T)

#checks
nrow(hcat2_base) == nrow(hcat2_base_nodeid)
length(unique(hcat2_base$HCAT2_code)) == length(unique(hcat2_base_nodeid$HCAT2_code))
length(unique(hcat2_base$HCAT2_name)) == length(unique(hcat2_base_nodeid$HCAT2_name))
length(unique(hcat2_base$HCAT2_code_aggregated_NL)) == length(unique(hcat2_base_nodeid$HCAT2_name_aggregated_NL))
length(unique(hcat2_base$HCAT2_code_aggregated_FR)) == length(unique(hcat2_base_nodeid$HCAT2_name_aggregated_FR))

#merge with availability
hcat2_base_nodeid_avail <- merge(hcat2_base_nodeid, hcat2_avail,by.x = 'HCAT2_code', by.y = 'hcat2_code', all.x = T)
hcat2_base_nodeid_avail$fr[is.na(hcat2_base_nodeid_avail$fr)] <- 0
hcat2_base_nodeid_avail$nl[is.na(hcat2_base_nodeid_avail$nl)] <- 0

table(hcat2_base_nodeid_avail$fr)
table(hcat2_base_nodeid_avail$nl)

#checks
nrow(hcat2_base) == nrow(hcat2_base_nodeid_avail)
length(unique(hcat2_base$HCAT2_code)) == length(unique(hcat2_base_nodeid_avail$HCAT2_code))
length(unique(hcat2_base$HCAT2_name)) == length(unique(hcat2_base_nodeid_avail$HCAT2_name))
length(unique(hcat2_base$HCAT2_code_aggregated_NL)) == length(unique(hcat2_base_nodeid_avail$HCAT2_name_aggregated_NL))
length(unique(hcat2_base$HCAT2_code_aggregated_FR)) == length(unique(hcat2_base_nodeid_avail$HCAT2_name_aggregated_FR))

#merge with color
hcat2_base_nodeid_avail_color <- merge(hcat2_base_nodeid_avail, hcat2_color[,c(1,2)], by.x = 'HCAT2_name_aggregated_NL', by.y = 'HCAT2_name')
colnames(hcat2_base_nodeid_avail_color)[grep('colorRGB', colnames(hcat2_base_nodeid_avail_color))] <- 'colorRGB_NL'

hcat2_base_nodeid_avail_color <- merge(hcat2_base_nodeid_avail_color, hcat2_color[,c(1,2)], by.x = 'HCAT2_name_aggregated_FR', by.y = 'HCAT2_name')
colnames(hcat2_base_nodeid_avail_color)[grep('^colorRGB$', colnames(hcat2_base_nodeid_avail_color))] <- 'colorRGB_FR'

hcat2_base_nodeid_avail_color$colorRGB_same <- ifelse(hcat2_base_nodeid_avail_color$colorRGB_NL == hcat2_base_nodeid_avail_color$colorRGB_FR, T, F)
table(hcat2_base_nodeid_avail_color$colorRGB_same)

#convert distro to percentage
hcat2_base_nodeid_avail_color$distro_perc_NL <- round((hcat2_base_nodeid_avail_color$distrib_NL / sum(hcat2_base_nodeid_avail_color$distrib_NL[!is.na(hcat2_base_nodeid_avail_color$distrib_NL)])) * 100, 2)
hcat2_base_nodeid_avail_color$distro_perc_FR <- round((hcat2_base_nodeid_avail_color$distrib_FR / sum(hcat2_base_nodeid_avail_color$distrib_FR[!is.na(hcat2_base_nodeid_avail_color$distrib_FR)])) * 100, 2)

write.csv(hcat2_base_nodeid_avail_color, '/eos/jeodpp/data/projects/REFOCUS/data/phylogentree/HCAT2mergedWithAggregation_allinfo.csv', row.names = F)
